@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use vars qw( $VERSION @EXPORT @EXPORT_OK $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '0.81';
+$VERSION   = '0.83';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
@@ -19,6 +19,7 @@ use constant is_insensitive_fs => (
         and (-s lc($0) || -1) == -s $0
 );
 
+use version;
 use Cwd ();
 use File::Path ();
 use File::Temp ();
@@ -35,8 +36,8 @@ Module::ScanDeps - Recursively scan Perl code for dependencies
 
 =head1 VERSION
 
-This document describes version 0.81 of Module::ScanDeps, released
-December 7, 2007.
+This document describes version 0.82 of Module::ScanDeps, released
+January 28, 2008.
 
 =head1 SYNOPSIS
 
@@ -284,6 +285,11 @@ my %Preload;
     'HTTP/Message.pm' => [ qw(
         URI/URL.pm          URI.pm
     ) ],
+    'Image/ExifTool.pm' => sub {
+        return( _glob_in_inc("Image/ExifTool", 1), qw(
+            File/RandomAccess.pm
+        ));
+    },
     'Image/Info.pm' => sub {
         return( _glob_in_inc("Image/Info", 1), qw(
             Image/TIFF.pm
@@ -699,7 +705,14 @@ sub scan_line {
             $CurrentPackage =~ s{::}{/}g;
             return;
         }
-        return if /^\s*(use|require)\s+[\d\._]+/;
+        # use VERSION:
+        if (/^\s*(?:use|require)\s+([\d\._]+)/) {
+          # include feaure.pm if we have 5.9.5 or better
+          if (version->new($1) >= version->new("5.9.5")) { # seems to catch 5.9, too (but not 5.9.4)
+            return "feature.pm";
+          }
+        }
+
         if (my ($autouse) = /^\s*use\s+autouse\s+(["'].*?["']|\w+)/)	
         {
             $autouse =~ s/["']//g;
@@ -1304,9 +1317,9 @@ Please submit bug reports to E<lt>bug-Module-ScanDeps@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002-2007 by
+Copyright 2002-2008 by
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>;
-2005-2007 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.
+2005-2008 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
